clear all
set more off
cd /*Files path here*/
use DataPiketty, clear


***********************************************************
/*Program for fixed effects estimation to be bootstrapped*/
***********************************************************
cap program drop fedaron
program fedaron, eclass
syntax anything[, num(integer 1)] /*num is the number of independent variables of interest*/
	local 0 `anything' 
	gettoken yvar 0 : 0 /*dependent variable*/
	gettoken xvars 0 : 0, match(par) /*covariates of interest*/
    gettoken covs 0 : 0, match(par) /*covariates to partial out (may not be estimated in some draws)*/
areg `yvar' `xvars' `covs', absorb(ccode)
gen samp=e(sample)
bysort ccode: egen tag=total(samp) /*Only reports as part of the sample countries which contribute some info (appear at least twice)*/
gen sampnew=samp
replace sampnew=0 if tag<2  /*Only reports as part of the sample countries which contribute some info*/
matrix b_all=e(b)
matrix V_all=e(V)
matrix b=b_all[1,1..`num']
matrix V=V_all[1..`num',1..`num']
matrix colnames b=`xvars'
matrix rownames V=`xvars'
matrix colnames V=`xvars'
egen observations=total(sampnew)
sum observations
local obs=r(mean)
drop samp  observations tag
ereturn post b V, obs(`obs') esample(sampnew)
end


/*Creation of variables*/
egen ccode=group(country)
sort ccode year
xtset ccode year

gen minusg=-d.y /*minus g from Madisson*/
gen pik_irate=irate-f.infrat-d.y_na /*irate from OECD data (net of inflation), minusg from PWT*/
gen pik_mpk=mpk_na-delta_k-d.y_na  

gen l1top1share=L1.top1share
gen l2top1share=L2.top1share
gen l3top1share=L3.top1share
gen l4top1share=L4.top1share
gen l5top1share=L5.top1share

gen lpop=log(pop2)
gen gpop=100*d.lpop
gen ygdp=log(gdppc)


/*Panel A: baseline*/
*Columns 1 and 2*
gen xvar=100*minusg
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(6)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  i.source i.year, fe 
xtreg top1share xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar

*Columns 3 and 4*
gen xvar=100*pik_irate
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(6)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  i.source i.year, fe 
xtreg top1share xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar

*Columns 5 and 6*
gen xvar=100*pik_mpk
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(6)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  i.source i.year, fe 
xtreg top1share xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar


/*Panel B: adds log of GDP per capita*/
*Columns 1 and 2*
gen xvar=100*minusg
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar ygdp) (i.source i.year), num(2)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar ygdp l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(7)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar ygdp i.source i.year, fe 
xtreg top1share xvar ygdp l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar

*Columns 3 and 4*
gen xvar=100*pik_irate
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar ygdp) (i.source i.year), num(2)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar ygdp l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(7)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar ygdp i.source i.year, fe 
xtreg top1share xvar ygdp l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar

*Columns 5 and 6*
gen xvar=100*pik_mpk
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar ygdp) (i.source i.year), num(2)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar ygdp l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(7)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar ygdp i.source i.year, fe 
xtreg top1share xvar ygdp l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar

/*Panel C: population growth*/
*Columns 1 and 2*
gen xvar=100*minusg
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar gpop) (i.source i.year), num(2)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar gpop l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(7)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar gpop i.source i.year, fe 
xtreg top1share xvar gpop l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar

*Columns 3 and 4*
gen xvar=100*pik_irate
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar gpop) (i.source i.year), num(2)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar gpop l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(7)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar gpop i.source i.year, fe 
xtreg top1share xvar gpop l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar

*Columns 5 and 6*
gen xvar=100*pik_mpk
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar gpop) (i.source i.year), num(2)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar gpop l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(7)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar gpop i.source i.year, fe 
xtreg top1share xvar gpop l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
drop xvar


/*Panel D: country trends*/
*Columns 1 and 2*
gen xvar=100*minusg
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year i.ccode#c.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year i.ccode#c.year), num(6)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  i.source i.year i.ccode#c.year, fe 
xtreg top1share xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year i.ccode#c.year, fe 
drop xvar

*Columns 3 and 4*
gen xvar=100*pik_irate
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year i.ccode#c.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year i.ccode#c.year), num(6)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  i.source i.year i.ccode#c.year, fe 
xtreg top1share xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year i.ccode#c.year, fe 
drop xvar

*Columns 5 and 6*
gen xvar=100*pik_mpk
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year i.ccode#c.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year i.ccode#c.year), num(6)

*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  i.source i.year i.ccode#c.year, fe 
xtreg top1share xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year i.ccode#c.year, fe 
drop xvar
