clear all
set more off
cd /*Files path here*/
use DataPiketty, clear

***********************************************************
/*Program for fixed effects estimation to be bootstrapped*/
***********************************************************
cap program drop fedaron
program fedaron, eclass
syntax anything[, num(integer 1)] /*num is the number of independent variables of interest*/
	local 0 `anything' 
	gettoken yvar 0 : 0 /*dependent variable*/
	gettoken xvars 0 : 0, match(par) /*covariates of interest*/
    gettoken covs 0 : 0, match(par) /*covariates to partial out (may not be estimated in some draws)*/
areg `yvar' `xvars' `covs', absorb(ccode)
gen samp=e(sample)
bysort ccode: egen tag=total(samp) /*Only reports as part of the sample countries which contribute some info (appear at least twice)*/
gen sampnew=samp
replace sampnew=0 if tag<2  /*Only reports as part of the sample countries which contribute some info*/
matrix b_all=e(b)
matrix V_all=e(V)
matrix b=b_all[1,1..`num']
matrix V=V_all[1..`num',1..`num']
matrix colnames b=`xvars'
matrix rownames V=`xvars'
matrix colnames V=`xvars'
egen observations=total(sampnew)
sum observations
local obs=r(mean)
drop samp  observations tag
ereturn post b V, obs(`obs') esample(sampnew)
end

/*Creation of variables*/
egen ccode=group(country)
sort ccode year
xtset ccode year

gen minusg=-d.y /*minus g from Madisson*/
gen pik_irate=irate-f.infrat-d.y_na /*irate from OECD data (net of inflation), minusg from PWT*/
gen pik_mpk=mpk_na-delta_k-d.y_na  

gen l1top5share=L1.top5share
gen l2top5share=L2.top5share
gen l3top5share=L3.top5share
gen l4top5share=L4.top5share
gen l5top5share=L5.top5share

tab year, gen(dyear)
tab ccode, gen(dcode)
tab source5, gen(dsource5)


/*******************Yearly regressions (top panel)***************************/
/*Panel A: common r-country g*/
gen xvar=100*minusg
xtset ccode year
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar

*Column 1*
*non-bootstrapped version*
xtset ccode year
xtreg top5share xvar i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar) (i.source5 i.year), num(1)

*Column 2*
*non-bootstrapped version*
xtset ccode year
xtreg top5share  l1top5share l2top5share l3top5share l4top5share l5top5share xvar i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar  l1top5share l2top5share l3top5share l4top5share l5top5share) (i.source5 i.year), num(6)


*Column 3*
*non-bootstrapped version*
xtset ccode year
xtreg top5share xvar  l1xvar l2xvar l3xvar l4xvar l1top5share l2top5share l3top5share l4top5share l5top5share i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar  l1xvar l2xvar l3xvar l4xvar l1top5share l2top5share l3top5share l4top5share l5top5share) (i.source5 i.year), num(10)

*Drop variables*
drop xvar l1xvar l2xvar l3xvar l4xvar


/*Panel B: i-pi-g*/
gen xvar=100*pik_irate
xtset ccode year
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar

*Column 4*
*non-bootstrapped version*
xtset ccode year
xtreg top5share xvar i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar) (i.source5 i.year), num(1)

*Column 5*
*non-bootstrapped version*
xtset ccode year
xtreg top5share  l1top5share l2top5share l3top5share l4top5share l5top5share xvar i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar  l1top5share l2top5share l3top5share l4top5share l5top5share) (i.source5 i.year), num(6)


*Column 6*
*non-bootstrapped version*
xtset ccode year
xtreg top5share xvar  l1xvar l2xvar l3xvar l4xvar l1top5share l2top5share l3top5share l4top5share l5top5share i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar  l1xvar l2xvar l3xvar l4xvar l1top5share l2top5share l3top5share l4top5share l5top5share) (i.source5 i.year), num(10)

*Drop variables*
drop xvar l1xvar l2xvar l3xvar l4xvar


/*Panel C: MPK-delta-g*/
gen xvar=100*pik_mpk
xtset ccode year
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar

*Column 7*
*non-bootstrapped version*
xtset ccode year
xtreg top5share xvar i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar) (i.source5 i.year), num(1)

*Column 8*
*non-bootstrapped version*
xtset ccode year
xtreg top5share  l1top5share l2top5share l3top5share l4top5share l5top5share xvar i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar  l1top5share l2top5share l3top5share l4top5share l5top5share) (i.source5 i.year), num(6)


*Column 9*
*non-bootstrapped version*
xtset ccode year
xtreg top5share xvar  l1xvar l2xvar l3xvar l4xvar l1top5share l2top5share l3top5share l4top5share l5top5share i.source5 i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5share (xvar  l1xvar l2xvar l3xvar l4xvar l1top5share l2top5share l3top5share l4top5share l5top5share) (i.source5 i.year), num(10)

*Drop variables*
drop xvar l1xvar l2xvar l3xvar l4xvar


/*******************Long regressions, 10 years gaps (Bottom panel)***************************/
keep if year<=2010
gen time=year-1
gen resid=time-10*floor(time/10)
gen period=10+time-resid
/*Fill each 10 year observation with closest year in -2,+2 window*/
gen top5dec=top5share if resid==9
bysort country: replace top5dec=top5share[_n-1] if resid==9 & top5dec==.
bysort country: replace top5dec=top5share[_n+1] if resid==9 & top5dec==.
bysort country: replace top5dec=top5share[_n-2] if resid==9 & top5dec==.
bysort country: replace top5dec=top5share[_n+2] if resid==9 & top5dec==.
gen source5dec=source5 if resid==9
bysort country: replace source5dec=source5[_n-1] if resid==9 & source5dec==.
bysort country: replace source5dec=source5[_n+1] if resid==9 & source5dec==.
bysort country: replace source5dec=source5[_n-2] if resid==9 & source5dec==.
bysort country: replace source5dec=source5[_n+2] if resid==9 & source5dec==.

*Collapses the data in such a way that the average r-g in the last 10 years is assigned to the dependent variable in 2010, 2000, 1990, and so on...
preserve
collapse  source5dec top5dec minusg pik_irate pik_mpk, by(country period) /*interest rates and growth are cummulative over the 10 year period before each observation*/
egen ccode=group(country)
xtset ccode period, delta(10)
gen ltop5dec=L.top5dec

/*Panel A: common r-country g*/
gen xvar=100*minusg

*Column 1*
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (xvar) (i.source5dec i.period), num(1)

*Column 2*
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top5dec ltop5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (ltop5dec xvar) (i.source5dec i.period), num(2)

drop xvar

/*Panel B: i-pi-g*/
gen xvar=100*pik_irate

*Column 4*
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (xvar) (i.source5dec i.period), num(1)

*Column 5*
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top5dec ltop5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (ltop5dec xvar) (i.source5dec i.period), num(2)

drop xvar

/*Panel C: MPK-delta-g*/
gen xvar=100*pik_mpk

*Column 7*
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (xvar) (i.source5dec i.period), num(1)

*Column 8*
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top5dec ltop5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (ltop5dec xvar) (i.source5dec i.period), num(2)

drop xvar
restore

/*******************Long regressions, 20 years gaps (Bottom panel, Columns 3,6,9)***************************/
drop time resid top5dec source5dec period
gen time=year-11
gen resid=time-20*floor(time/20)
gen period=30+time-resid
gen top5dec=top5share if resid==19
gen source5dec=source5 if resid==19
bysort country: replace top5dec=top5share[_n-1] if resid==19 & top5dec==.
bysort country: replace top5dec=top5share[_n+1] if resid==19 & top5dec==.
bysort country: replace top5dec=top5share[_n-2] if resid==19 & top5dec==.
bysort country: replace top5dec=top5share[_n+2] if resid==19 & top5dec==.
bysort country: replace source5dec=source5[_n-1] if resid==19 & source5dec==.
bysort country: replace source5dec=source5[_n+1] if resid==19 & source5dec==.
bysort country: replace source5dec=source5[_n-2] if resid==19 & source5dec==.
bysort country: replace source5dec=source5[_n+2] if resid==19 & source5dec==.

*Collapses the data in such a way that the average r-g in the last 20 years is assigned to the dependent variable in 2010, 1990, and so on...
preserve
collapse  source5dec top5dec minusg pik_irate pik_mpk, by(country period)
egen ccode=group(country)

/*Panel A: common r-country g*/
gen xvar=100*minusg

*Column 3*
*non-bootstrapped version*
xtset ccode period, delta(20)
xtreg top5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (xvar) (i.source5dec i.period), num(1)

drop xvar

/*Panel B: i-pi-g*/
gen xvar=100*pik_irate

*Column 6*
*non-bootstrapped version*
xtset ccode period, delta(20)
xtreg top5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (xvar) (i.source5dec i.period), num(1)

drop xvar

/*Panel C: MPK-delta-g*/
gen xvar=100*pik_mpk

*Column 9*
*non-bootstrapped version*
xtset ccode period, delta(20)
xtreg top5dec xvar i.source5dec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top5dec (xvar) (i.source5dec i.period), num(1)

drop xvar
restore




