clear all
set more off
cd /*Files path here*/
use DataPiketty, clear

***********************************************************
/*Program for fixed effects estimation to be bootstrapped*/
***********************************************************
cap program drop fedaron
program fedaron, eclass
syntax anything[, num(integer 1)] /*num is the number of independent variables of interest*/
	local 0 `anything' 
	gettoken yvar 0 : 0 /*dependent variable*/
	gettoken xvars 0 : 0, match(par) /*covariates of interest*/
    gettoken covs 0 : 0, match(par) /*covariates to partial out (may not be estimated in some draws)*/
areg `yvar' `xvars' `covs', absorb(ccode)
gen samp=e(sample)
bysort ccode: egen tag=total(samp) /*Only reports as part of the sample countries which contribute some info (appear at least twice)*/
gen sampnew=samp
replace sampnew=0 if tag<2  /*Only reports as part of the sample countries which contribute some info*/
matrix b_all=e(b)
matrix V_all=e(V)
matrix b=b_all[1,1..`num']
matrix V=V_all[1..`num',1..`num']
matrix colnames b=`xvars'
matrix rownames V=`xvars'
matrix colnames V=`xvars'
egen observations=total(sampnew)
sum observations
local obs=r(mean)
drop samp  observations tag
ereturn post b V, obs(`obs') esample(sampnew)
end

/*Creation of variables*/
egen ccode=group(country)
sort ccode year
xtset ccode year

gen minusg=-d.y_na /*minus g from PWT in this sub-sample*/
gen pik_irate=irate-f.infrat-d.y_na /*irate from OECD data (net of inflation), minusg from PWT*/
gen pik_mpk=mpk_na-delta_k-d.y_na  

gen l1top1share=L1.top1share
gen l2top1share=L2.top1share
gen l3top1share=L3.top1share
gen l4top1share=L4.top1share
gen l5top1share=L5.top1share

tab year, gen(dyear)
tab ccode, gen(dcode)
tab source, gen(dsource)


/*******************Yearly regressions (top panel)***************************/

/*Common panel*/
gen xvar=100*pik_irate
xtreg top1share xvar i.source i.year, fe r
gen samp1=e(sample)

xtreg top1share xvar l(1/5).top1share i.source i.year, fe r
gen samp2=e(sample)

xtreg top1share l(0/4).xvar l(1/5).top1share i.source i.year, fe r
gen samp3=e(sample)
drop xvar

/*Panel A: common r-country g*/
gen xvar=100*minusg
xtset ccode year
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar

*Column 1*
preserve
keep if samp1==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year), num(1)
restore

*Column 2*
preserve
keep if samp2==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share  l1top1share l2top1share l3top1share l4top1share l5top1share xvar i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar  l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(6)
restore

*Column 3*
preserve
keep if samp3==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  l1xvar l2xvar l3xvar l4xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar  l1xvar l2xvar l3xvar l4xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(10)
restore

*Drop variables*
drop xvar l1xvar l2xvar l3xvar l4xvar


/*Panel B: i-pi-g*/
gen xvar=100*pik_irate
xtset ccode year
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar

*Column 4*
preserve
keep if samp1==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year), num(1)
restore

*Column 5*
preserve
keep if samp2==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share  l1top1share l2top1share l3top1share l4top1share l5top1share xvar i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar  l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(6)
restore

*Column 6*
preserve
keep if samp3==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  l1xvar l2xvar l3xvar l4xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar  l1xvar l2xvar l3xvar l4xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(10)
restore

*Drop variables*
drop xvar l1xvar l2xvar l3xvar l4xvar


/*Panel C: MPK-delta-g*/
gen xvar=100*pik_mpk
xtset ccode year
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar

*Column 7*
preserve
keep if samp1==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar) (i.source i.year), num(1)
restore

*Column 8*
preserve
keep if samp2==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share  l1top1share l2top1share l3top1share l4top1share l5top1share xvar i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar  l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(6)
restore

*Column 9*
preserve
keep if samp3==1
*non-bootstrapped version*
xtset ccode year
xtreg top1share xvar  l1xvar l2xvar l3xvar l4xvar l1top1share l2top1share l3top1share l4top1share l5top1share i.source i.year, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1share (xvar  l1xvar l2xvar l3xvar l4xvar l1top1share l2top1share l3top1share l4top1share l5top1share) (i.source i.year), num(10)
restore

*Drop variables*
drop xvar l1xvar l2xvar l3xvar l4xvar


/*******************Long regressions, 10 years gaps (Bottom panel)***************************/
keep if year<=2010
gen time=year-1
gen resid=time-10*floor(time/10)
gen period=10+time-resid
/*Fill each 10 year observation with closest year in -2,+2 window*/
gen top1dec=top1share if resid==9
bysort country: replace top1dec=top1share[_n-1] if resid==9 & top1dec==.
bysort country: replace top1dec=top1share[_n+1] if resid==9 & top1dec==.
bysort country: replace top1dec=top1share[_n-2] if resid==9 & top1dec==.
bysort country: replace top1dec=top1share[_n+2] if resid==9 & top1dec==.
gen sourcedec=source if resid==9
bysort country: replace sourcedec=source[_n-1] if resid==9 & sourcedec==.
bysort country: replace sourcedec=source[_n+1] if resid==9 & sourcedec==.
bysort country: replace sourcedec=source[_n-2] if resid==9 & sourcedec==.
bysort country: replace sourcedec=source[_n+2] if resid==9 & sourcedec==.
save temp.dta, replace

*Collapses the data in such a way that the average r-g in the last 10 years is assigned to the dependent variable in 2010, 2000, 1990, and so on...
collapse  sourcedec top1dec minusg pik_irate pik_mpk, by(country period) /*interest rates and growth are cummulative over the 10 year period before each observation*/
egen ccode=group(country)
xtset ccode period, delta(10)
gen ltop1dec=L.top1dec

/*Common panel*/
gen xvar=100*pik_irate
xtreg top1dec xvar i.sourcedec i.period, fe r
gen samp=e(sample)
bysort ccode: egen tag=total(samp)
xtreg top1dec xvar i.sourcedec i.period if tag>=2, fe r
drop tag samp
gen samp1=e(sample)

xtreg top1dec ltop1dec xvar i.sourcedec i.period, fe r
gen samp=e(sample)
bysort ccode: egen tag=total(samp)
xtreg top1dec ltop1dec xvar i.sourcedec i.period if tag>=2, fe r
drop tag samp
gen samp2=e(sample)
drop xvar

/*Panel A: common r-country g*/
gen xvar=100*minusg

*Column 1*
preserve
keep if samp1==1
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (xvar) (i.sourcedec i.period), num(1)
restore

*Column 2*
preserve
keep if samp2==1
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top1dec ltop1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (ltop1dec xvar) (i.sourcedec i.period), num(2)
restore

drop xvar

/*Panel B: i-pi-g*/
gen xvar=100*pik_irate

*Column 4*
preserve
keep if samp1==1
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (xvar) (i.sourcedec i.period), num(1)
restore

*Column 5*
preserve
keep if samp2==1
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top1dec ltop1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (ltop1dec xvar) (i.sourcedec i.period), num(2)
restore

drop xvar


/*Panel C: MPK-delta-g*/
gen xvar=100*pik_mpk

*Column 7*
preserve
keep if samp1==1
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (xvar) (i.sourcedec i.period), num(1)
restore

*Column 8*
preserve
keep if samp2==1
*non-bootstrapped version*
xtset ccode period, delta(10)
xtreg top1dec ltop1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (ltop1dec xvar) (i.sourcedec i.period), num(2)
restore

drop xvar


/*******************Long regressions, 20 years gaps (Bottom panel, Columns 3,6,9)***************************/
use temp.dta, clear
drop time resid top1dec sourcedec period
gen time=year-11
gen resid=time-20*floor(time/20)
gen period=30+time-resid
gen top1dec=top1share if resid==19
gen sourcedec=source if resid==19
bysort country: replace top1dec=top1share[_n-1] if resid==19 & top1dec==.
bysort country: replace top1dec=top1share[_n+1] if resid==19 & top1dec==.
bysort country: replace top1dec=top1share[_n-2] if resid==19 & top1dec==.
bysort country: replace top1dec=top1share[_n+2] if resid==19 & top1dec==.
bysort country: replace sourcedec=source[_n-1] if resid==19 & sourcedec==.
bysort country: replace sourcedec=source[_n+1] if resid==19 & sourcedec==.
bysort country: replace sourcedec=source[_n-2] if resid==19 & sourcedec==.
bysort country: replace sourcedec=source[_n+2] if resid==19 & sourcedec==.

*Collapses the data in such a way that the average r-g in the last 20 years is assigned to the dependent variable in 2010, 1990, and so on...
preserve
collapse  sourcedec top1dec minusg pik_irate pik_mpk, by(country period)
egen ccode=group(country)

/*Sample restriction*/
gen xvar=100*pik_irate
xtreg top1dec xvar i.sourcedec i.period if period>=1970, fe r
gen samp=e(sample)
bysort ccode: egen tag=total(samp)
xtreg top1dec xvar i.sourcedec i.period if period>=1970&tag>=2, fe r
drop tag samp
gen samp3=e(sample)
drop xvar
keep if  samp3==1


/*Panel A: common r-country g*/
gen xvar=100*minusg

*Column 3*
*non-bootstrapped version*
xtset ccode period, delta(20)
xtreg top1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (xvar) (i.sourcedec i.period), num(1)

drop xvar

/*Panel B: i-pi-g*/
gen xvar=100*pik_irate

*Column 6*
*non-bootstrapped version*
xtset ccode period, delta(20)
xtreg top1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (xvar) (i.sourcedec i.period), num(1)

drop xvar

/*Panel C: MPK-delta-g*/
gen xvar=100*pik_mpk

*Column 9*
*non-bootstrapped version*
xtset ccode period, delta(20)
xtreg top1dec xvar i.sourcedec i.period, fe 
*bootstrap version in tables*
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron top1dec (xvar) (i.sourcedec i.period), num(1)

drop xvar
restore




