clear all
set more off
cd /*Files path here*/


***********************************************************
/*Program for fixed effects estimation to be bootstrapped*/
***********************************************************
cap program drop fedaron
program fedaron, eclass
syntax anything[, num(integer 1)] /*num is the number of independent variables of interest*/
	local 0 `anything' 
	gettoken yvar 0 : 0 /*dependent variable*/
	gettoken xvars 0 : 0, match(par) /*covariates of interest*/
    gettoken covs 0 : 0, match(par) /*covariates to partial out (may not be estimated in some draws)*/
areg `yvar' `xvars' `covs', absorb(ccode)
gen samp=e(sample)
bysort ccode: egen tag=total(samp) /*Only reports as part of the sample countries which contribute some info (appear at least twice)*/
gen sampnew=samp
replace sampnew=0 if tag<2  /*Only reports as part of the sample countries which contribute some info*/
matrix b_all=e(b)
matrix V_all=e(V)
matrix b=b_all[1,1..`num']
matrix V=V_all[1..`num',1..`num']
matrix colnames b=`xvars'
matrix rownames V=`xvars'
matrix colnames V=`xvars'
egen observations=total(sampnew)
sum observations
local obs=r(mean)
drop samp  observations tag
ereturn post b V, obs(`obs') esample(sampnew)
end

/*Creation of variables*/
use DataPiketty, clear
egen ccode=group(country)
sort ccode year
xtset ccode year

gen minusg=-d.y_na /*minus g from PWT in this sample*/
gen pik_irate=irate-f.infrat-d.y_na /*irate from OECD data (net of inflation), minusg from PWT*/

/*******************Capital share from the PWT****************/

gen capsh=100-labsh
gen l1capsh=L1.capsh
gen l2capsh=L2.capsh
gen l3capsh=L3.capsh
gen l4capsh=L4.capsh
gen l5capsh=L5.capsh

/*******************Yearly exercise***************************/

/*Panel A: common r-country g*/
preserve
gen xvar=100*minusg
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar
keep if year>=1990 /*Restrict PWT sample to years without imputations*/
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar) (i.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar l1capsh l2capsh l3capsh l4capsh l5capsh) (i.year), num(6) 
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar l1xvar l2xvar l3xvar l4xvar l1capsh l2capsh l3capsh l4capsh l5capsh) (i.year), num(10) 

*non-bootstrapped versions*
xtset ccode year
xtreg capsh xvar i.year, fe 
xtreg capsh xvar l1capsh l2capsh l3capsh l4capsh l5capsh i.year, fe 
xtreg capsh xvar l1xvar l2xvar l3xvar l4xvar l1capsh l2capsh l3capsh l4capsh l5capsh  i.year, fe 
restore

/*Panel B: i-pi-g*/
preserve
gen xvar=100*pik_irate
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar
keep if year>=1990 /*Restrict PWT sample to years without imputations*/
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar) (i.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar l1capsh l2capsh l3capsh l4capsh l5capsh) (i.year), num(6) 
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar l1xvar l2xvar l3xvar l4xvar l1capsh l2capsh l3capsh l4capsh l5capsh) (i.year), num(10) 

*non-bootstrapped versions*
xtset ccode year
xtreg capsh xvar i.year, fe 
xtreg capsh xvar l1capsh l2capsh l3capsh l4capsh l5capsh i.year, fe 
xtreg capsh xvar l1xvar l2xvar l3xvar l4xvar l1capsh l2capsh l3capsh l4capsh l5capsh  i.year, fe 
restore


/*******************Long regressions***************************/
preserve
keep if year<=2010
gen time=year-1
gen resid=time-10*floor(time/10)
gen period=10+time-resid
gen capshdec=capsh if resid==9

collapse capshdec minusg pik_irate, by(country period) /*interest rates and growth are cummulative over the 10 year period before each observation*/
egen ccode=group(country)
xtset ccode period, delta(10)
gen l1capshdec=l.capshdec
keep if period>=1990

/*Panel A: common r-country g*/
gen xvar=100*minusg
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar) (i.period), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar l1capshdec) (i.period), num(2)

*non-bootstrapped versions*
xtset ccode period, delta(10)
xtreg capshdec xvar i.period, fe 
xtreg capshdec xvar l1capshdec i.period, fe 
drop xvar


/*Panel B: i-pi-g*/
gen xvar=100*pik_irate
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar) (i.period), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar l1capshdec) (i.period), num(2)

*non-bootstrapped versions*
xtset ccode period, delta(10)
xtreg capshdec xvar i.period, fe 
xtreg capshdec xvar l1capshdec i.period, fe 
drop xvar

restore


preserve
keep if year<=2010
gen time=year-11
gen resid=time-20*floor(time/20)
gen period=30+time-resid
gen capshdec=capsh if resid==19

collapse  capshdec minusg pik_irate, by(country period)
egen ccode=group(country)
keep if period>=1990

/*Panel A: common r-country g*/
gen xvar=100*minusg
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar) (i.period), num(1)

*non-bootstrapped versions*
xtset ccode period, delta(20)
xtreg capshdec xvar i.period, fe 
drop xvar

/*Panel B: i-pi-g*/
gen xvar=100*pik_irate
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar) (i.period), num(1)

*non-bootstrapped versions*
xtset ccode period, delta(20)
xtreg capshdec xvar i.period, fe 
drop xvar

restore




/*Creation of variables*/
use DataPiketty, clear
egen ccode=group(country)
sort ccode year
xtset ccode year

gen minusg=-d.y /*minus g from Madisson*/
gen pik_irate=irate-f.infrat-d.y_na /*irate from OECD data (net of inflation), minusg from PWT*/

/*******************Capital share from Karabarbounis and Neiman****************/

gen capsh=100-labsh_kn
gen l1capsh=L1.capsh
gen l2capsh=L2.capsh
gen l3capsh=L3.capsh
gen l4capsh=L4.capsh
gen l5capsh=L5.capsh

/*******************Yearly exercise***************************/

/*Panel A: common r-country g*/
preserve
gen xvar=100*minusg
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar
keep if year>=1990 /*Restrict PWT sample to years without imputations*/
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar) (i.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar l1capsh l2capsh l3capsh l4capsh l5capsh) (i.year), num(6) 
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar l1xvar l2xvar l3xvar l4xvar l1capsh l2capsh l3capsh l4capsh l5capsh) (i.year), num(10) 

*non-bootstrapped versions*
xtset ccode year
xtreg capsh xvar i.year, fe 
xtreg capsh xvar l1capsh l2capsh l3capsh l4capsh l5capsh i.year, fe 
xtreg capsh xvar l1xvar l2xvar l3xvar l4xvar l1capsh l2capsh l3capsh l4capsh l5capsh  i.year, fe 
restore

/*Panel B: i-pi-g*/
preserve
gen xvar=100*pik_irate
gen l1xvar=L1.xvar
gen l2xvar=L2.xvar
gen l3xvar=L3.xvar
gen l4xvar=L4.xvar
keep if year>=1990 /*Restrict PWT sample to years without imputations*/
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar) (i.year), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar l1capsh l2capsh l3capsh l4capsh l5capsh) (i.year), num(6) 
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capsh (xvar l1xvar l2xvar l3xvar l4xvar l1capsh l2capsh l3capsh l4capsh l5capsh) (i.year), num(10) 

*non-bootstrapped versions*
xtset ccode year
xtreg capsh xvar i.year, fe 
xtreg capsh xvar l1capsh l2capsh l3capsh l4capsh l5capsh i.year, fe 
xtreg capsh xvar l1xvar l2xvar l3xvar l4xvar l1capsh l2capsh l3capsh l4capsh l5capsh  i.year, fe 
restore


/*******************Long regressions***************************/
preserve
keep if year<=2010
gen time=year-1
gen resid=time-10*floor(time/10)
gen period=10+time-resid
gen capshdec=capsh if resid==9

collapse capshdec minusg pik_irate, by(country period) /*interest rates and growth are cummulative over the 10 year period before each observation*/
egen ccode=group(country)
xtset ccode period, delta(10)
gen l1capshdec=l.capshdec
keep if period>=1960

/*Panel A: common r-country g*/
gen xvar=100*minusg
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar) (i.period), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar l1capshdec) (i.period), num(2)

*non-bootstrapped versions*
xtset ccode period, delta(10)
xtreg capshdec xvar i.period, fe 
xtreg capshdec xvar l1capshdec i.period, fe 
drop xvar


/*Panel B: i-pi-g*/
gen xvar=100*pik_irate
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar) (i.period), num(1)
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar l1capshdec) (i.period), num(2)

*non-bootstrapped versions*
xtset ccode period, delta(10)
xtreg capshdec xvar i.period, fe 
xtreg capshdec xvar l1capshdec i.period, fe 
drop xvar

restore


preserve
keep if year<=2010
gen time=year-11
gen resid=time-20*floor(time/20)
gen period=30+time-resid
gen capshdec=capsh if resid==19

collapse  capshdec minusg pik_irate, by(country period)
egen ccode=group(country)
keep if period>=1970

/*Panel A: common r-country g*/
gen xvar=100*minusg
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar) (i.period), num(1)

*non-bootstrapped versions*
xtset ccode period, delta(20)
xtreg capshdec xvar i.period, fe 
drop xvar

/*Panel B: i-pi-g*/
gen xvar=100*pik_irate
xtset, clear
bootstrap, seed(10101) cluster(ccode) reps(400): fedaron capshdec (xvar) (i.period), num(1)

*non-bootstrapped versions*
xtset ccode period, delta(20)
xtreg capshdec xvar i.period, fe 
drop xvar

restore
